Affected by GO-2025-4261
and 1 other vulnerabilities
GO-2025-4261 : Gitea allows attackers to add attachments with forbidden file extensions in code.gitea.io/gitea
GO-2026-6080 : Gitea: Branch Protection Bypass via PR Retargeting Preserves Stale `official` Approval Flag in go-gitea/gitea
Discover Packages
code.gitea.io/gitea
modules
indexer
stats
package
Version:
v1.26.4
Opens a new window with list of versions in this module.
Published: Jun 21, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Init initialize the repo indexer
UpdateRepoIndexer update a repository's entries in the indexer
DBIndexer implements Indexer interface to use database's like search
Index repository status function
type Indexer interface {
Index(id int64 ) error
Close()
}
Indexer defines an interface to index repository stats
TODO: this indexer is quite different from the others, maybe this package should be moved out from module/indexer
Source Files
¶
Click to show internal directories.
Click to hide internal directories.